<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="es">
<context>
    <name>About</name>
    <message>
        <location filename="../qml/About.qml" line="27"/>
        <source>About %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/About.qml" line="46"/>
        <source>Information</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/About.qml" line="49"/>
        <source>Thanks!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/About.qml" line="52"/>
        <source>License</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/About.qml" line="86"/>
        <source>Version %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/About.qml" line="90"/>
        <source>Using Qt %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/About.qml" line="94"/>
        <source>Website</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/About.qml" line="103"/>
        <source>Webcam capture application.</source>
        <translation type="unfinished">Aplicación de captura para la webcam.</translation>
    </message>
    <message>
        <location filename="../qml/About.qml" line="106"/>
        <source>A simple webcam application for picture and video capture.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/About.qml" line="122"/>
        <source>Thanks to all these cool people that helped contributing to Webcamoid all these years.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/About.qml" line="149"/>
        <source>Close</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>AddMedia</name>
    <message>
        <location filename="../qml/AddMedia.qml" line="28"/>
        <source>Add new media</source>
        <translation>Añadir nuevo medio</translation>
    </message>
    <message>
        <location filename="../qml/AddMedia.qml" line="67"/>
        <source>Description</source>
        <translation>Descripción</translation>
    </message>
    <message>
        <location filename="../qml/AddMedia.qml" line="74"/>
        <source>Insert media description</source>
        <translation>Ingresar descripción del medio</translation>
    </message>
    <message>
        <location filename="../qml/AddMedia.qml" line="81"/>
        <source>Media file</source>
        <translation>Archivo de medios</translation>
    </message>
    <message>
        <location filename="../qml/AddMedia.qml" line="89"/>
        <source>Select media file</source>
        <translation>Seleccionar archivo de medios</translation>
    </message>
    <message>
        <location filename="../qml/AddMedia.qml" line="96"/>
        <source>Search</source>
        <translation>Buscar</translation>
    </message>
    <message>
        <location filename="../qml/AddMedia.qml" line="116"/>
        <source>Ok</source>
        <translation>Aceptar</translation>
    </message>
    <message>
        <location filename="../qml/AddMedia.qml" line="141"/>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <location filename="../qml/AddMedia.qml" line="151"/>
        <source>Choose the file to add as media</source>
        <translation>Escoja el archivo de medios</translation>
    </message>
</context>
<context>
    <name>AudioConfig</name>
    <message>
        <location filename="../qml/AudioConfig.qml" line="117"/>
        <source>Outputs</source>
        <translation>Salidas</translation>
    </message>
    <message>
        <location filename="../qml/AudioConfig.qml" line="121"/>
        <source>Select the output device for audio playing</source>
        <translation>Seleccione el dispositivo de salida para reproducir el audio</translation>
    </message>
    <message>
        <location filename="../qml/AudioConfig.qml" line="134"/>
        <source>Inputs</source>
        <translation>Entradas</translation>
    </message>
    <message>
        <location filename="../qml/AudioConfig.qml" line="137"/>
        <source>Select the device for audio capturing</source>
        <translation>Seleccione el dispositivo para la captura del audio</translation>
    </message>
    <message>
        <location filename="../qml/AudioConfig.qml" line="193"/>
        <location filename="../qml/AudioConfig.qml" line="295"/>
        <source>Silence</source>
        <translation>Silenciar</translation>
    </message>
</context>
<context>
    <name>AudioInfo</name>
    <message>
        <location filename="../qml/AudioInfo.qml" line="199"/>
        <source>Description</source>
        <translation>Descripción</translation>
    </message>
    <message>
        <location filename="../qml/AudioInfo.qml" line="214"/>
        <location filename="../qml/AudioInfo.qml" line="221"/>
        <source>Device description</source>
        <translation>Descripción del dispositivo</translation>
    </message>
    <message>
        <location filename="../qml/AudioInfo.qml" line="229"/>
        <location filename="../qml/AudioInfo.qml" line="244"/>
        <location filename="../qml/AudioInfo.qml" line="251"/>
        <source>Device id</source>
        <translation>Identificación del dispositivo</translation>
    </message>
    <message>
        <location filename="../qml/AudioInfo.qml" line="266"/>
        <source>Sample Format</source>
        <translation>Formato de la muestra</translation>
    </message>
    <message>
        <location filename="../qml/AudioInfo.qml" line="292"/>
        <source>Channels</source>
        <translation>Canales</translation>
    </message>
    <message>
        <location filename="../qml/AudioInfo.qml" line="318"/>
        <source>Sample Rate</source>
        <translation>Frequencia de muestreo</translation>
    </message>
</context>
<context>
    <name>CodecConfigs</name>
    <message>
        <location filename="../../../libAvKys/Plugins/MultiSink/share/qml/CodecConfigs.qml" line="27"/>
        <source>Configure %1</source>
        <translation>Configuración %1</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/MultiSink/share/qml/CodecConfigs.qml" line="112"/>
        <source>Search option</source>
        <translation>Opciones de búsqueda</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/MultiSink/share/qml/CodecConfigs.qml" line="126"/>
        <source>Reset</source>
        <translation>Restablecer</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/MultiSink/share/qml/CodecConfigs.qml" line="141"/>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/MultiSink/share/qml/CodecConfigs.qml" line="151"/>
        <source>OK</source>
        <translation>Aceptar</translation>
    </message>
</context>
<context>
    <name>ConfigBar</name>
    <message>
        <location filename="../qml/ConfigBar.qml" line="44"/>
        <source>Output</source>
        <translation>Salida</translation>
    </message>
    <message>
        <location filename="../qml/ConfigBar.qml" line="48"/>
        <source>General Options</source>
        <translation>Opciones generales</translation>
    </message>
    <message>
        <location filename="../qml/ConfigBar.qml" line="52"/>
        <source>Plugins Configs</source>
        <translation>Configuración de plugins</translation>
    </message>
    <message>
        <location filename="../qml/ConfigBar.qml" line="56"/>
        <source>Updates</source>
        <translation>Actualizaciones</translation>
    </message>
</context>
<context>
    <name>EffectBar</name>
    <message>
        <location filename="../qml/EffectBar.qml" line="122"/>
        <source>Search effect...</source>
        <translation>Buscar efecto...</translation>
    </message>
    <message>
        <location filename="../qml/EffectBar.qml" line="168"/>
        <source>None</source>
        <translation>Ninguno</translation>
    </message>
</context>
<context>
    <name>EffectConfig</name>
    <message>
        <location filename="../qml/EffectConfig.qml" line="96"/>
        <location filename="../qml/EffectConfig.qml" line="103"/>
        <source>Plugin id</source>
        <translation>Identificación del plugin</translation>
    </message>
    <message>
        <location filename="../qml/EffectConfig.qml" line="83"/>
        <source>Description</source>
        <translation>Descripción</translation>
    </message>
    <message>
        <location filename="../qml/EffectConfig.qml" line="90"/>
        <source>Plugin description</source>
        <translation>Descripción del plugin</translation>
    </message>
    <message>
        <location filename="../qml/EffectConfig.qml" line="119"/>
        <source>Remove</source>
        <translation>Eliminar</translation>
    </message>
    <message>
        <location filename="../qml/EffectConfig.qml" line="119"/>
        <source>Add</source>
        <translation>Añadir</translation>
    </message>
</context>
<context>
    <name>GeneralConfig</name>
    <message>
        <location filename="../qml/GeneralConfig.qml" line="46"/>
        <source>Play webcam on start</source>
        <translation>Reproducir webcam al inicio</translation>
    </message>
    <message>
        <location filename="../qml/GeneralConfig.qml" line="52"/>
        <source>Enable advanced effects mode</source>
        <translation>Habilitar el modo de efectos avanzados</translation>
    </message>
    <message>
        <location filename="../qml/GeneralConfig.qml" line="58"/>
        <source>Frameworks &amp; libraries</source>
        <translation>Frameworks y librerías</translation>
    </message>
    <message>
        <location filename="../qml/GeneralConfig.qml" line="68"/>
        <source>Video capture</source>
        <translation>Captura de vídeo</translation>
    </message>
    <message>
        <location filename="../qml/GeneralConfig.qml" line="78"/>
        <source>Desktop capture</source>
        <translation>Captura del escritorio</translation>
    </message>
    <message>
        <location filename="../qml/GeneralConfig.qml" line="88"/>
        <source>Audio capture/play</source>
        <translation>Capturar/Reproducir audio</translation>
    </message>
    <message>
        <location filename="../qml/GeneralConfig.qml" line="98"/>
        <source>Video convert</source>
        <translation>Convertir vídeo</translation>
    </message>
    <message>
        <location filename="../qml/GeneralConfig.qml" line="108"/>
        <source>Audio convert</source>
        <translation>Convertir audio</translation>
    </message>
    <message>
        <location filename="../qml/GeneralConfig.qml" line="149"/>
        <source>Virtual camera driver</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/GeneralConfig.qml" line="118"/>
        <source>Video playback</source>
        <translation>Reproducción de vídeo</translation>
    </message>
    <message>
        <location filename="../qml/GeneralConfig.qml" line="128"/>
        <source>Video record</source>
        <translation>Grabación de vídeo</translation>
    </message>
    <message>
        <location filename="../qml/GeneralConfig.qml" line="138"/>
        <source>Root method</source>
        <translation>Método inicial</translation>
    </message>
</context>
<context>
    <name>MediaBar</name>
    <message>
        <location filename="../qml/MediaBar.qml" line="62"/>
        <source>No webcams found</source>
        <translation>No hay webcams conectadas</translation>
    </message>
</context>
<context>
    <name>MediaConfig</name>
    <message>
        <location filename="../qml/MediaConfig.qml" line="54"/>
        <source>Description</source>
        <translation>Descripción</translation>
    </message>
    <message>
        <location filename="../qml/MediaConfig.qml" line="61"/>
        <source>Insert media description</source>
        <translation>Insertar descripción del medio</translation>
    </message>
    <message>
        <location filename="../qml/MediaConfig.qml" line="68"/>
        <source>Media UID</source>
        <translation>UID de medios</translation>
    </message>
    <message>
        <location filename="../qml/MediaConfig.qml" line="75"/>
        <source>Select media file</source>
        <translation>Seleccione el archivo de medios</translation>
    </message>
    <message>
        <location filename="../qml/MediaConfig.qml" line="90"/>
        <source>Edit</source>
        <translation>Editar</translation>
    </message>
    <message>
        <location filename="../qml/MediaConfig.qml" line="98"/>
        <source>Remove</source>
        <translation>Eliminar</translation>
    </message>
</context>
<context>
    <name>MediaTools</name>
    <message>
        <location filename="../../src/mediatools.cpp" line="223"/>
        <source>Daily Build</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>OutputConfig</name>
    <message>
        <location filename="../qml/OutputConfig.qml" line="55"/>
        <source>Virtual camera</source>
        <translation>Camara virtual</translation>
    </message>
</context>
<context>
    <name>PhotoWidget</name>
    <message>
        <location filename="../qml/PhotoWidget.qml" line="35"/>
        <source>%1 seconds</source>
        <translation>%1 segundos</translation>
    </message>
    <message>
        <location filename="../qml/PhotoWidget.qml" line="56"/>
        <source>Now</source>
        <translation>Ahora</translation>
    </message>
    <message>
        <location filename="../qml/PhotoWidget.qml" line="80"/>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <location filename="../qml/PhotoWidget.qml" line="80"/>
        <source>Shot!</source>
        <translation>¡Disparado!</translation>
    </message>
    <message>
        <location filename="../qml/PhotoWidget.qml" line="111"/>
        <source>Use flash</source>
        <translation>Usar flash</translation>
    </message>
</context>
<context>
    <name>PluginConfig</name>
    <message>
        <location filename="../qml/PluginConfig.qml" line="110"/>
        <source>Use this page for configuring the plugins search paths.&lt;br /&gt;&lt;b&gt;Don&apos;t touch nothing unless you know what you are doing&lt;/b&gt;.</source>
        <translation>Use esta página para configurar las rutas de búsqueda de plugins.&lt;br /&gt;&lt;b&gt;No modifíque nada a menos que sepa lo que está haciendo&lt;/b&gt;.</translation>
    </message>
    <message>
        <location filename="../qml/PluginConfig.qml" line="115"/>
        <source>Extra search paths</source>
        <translation>Rutas de búsqueda adicionales</translation>
    </message>
    <message>
        <location filename="../qml/PluginConfig.qml" line="124"/>
        <source>Search plugins in subfolders.</source>
        <translation>Buscar plugins en sub-directorios.</translation>
    </message>
    <message>
        <location filename="../qml/PluginConfig.qml" line="134"/>
        <source>Add</source>
        <translation>Añadir</translation>
    </message>
    <message>
        <location filename="../qml/PluginConfig.qml" line="141"/>
        <source>Remove</source>
        <translation>Eliminar</translation>
    </message>
    <message>
        <location filename="../qml/PluginConfig.qml" line="207"/>
        <source>Plugins list</source>
        <translation>Lista de plugins</translation>
    </message>
    <message>
        <location filename="../qml/PluginConfig.qml" line="216"/>
        <source>Refresh</source>
        <translation>Actualizar</translation>
    </message>
    <message>
        <location filename="../qml/PluginConfig.qml" line="226"/>
        <source>Disable</source>
        <translation>Deshabilitar</translation>
    </message>
    <message>
        <location filename="../qml/PluginConfig.qml" line="226"/>
        <source>Enable</source>
        <translation>Habilitar</translation>
    </message>
    <message>
        <location filename="../qml/PluginConfig.qml" line="308"/>
        <source>Add plugins search path</source>
        <translation>Añadir ruta de búsqueda para los plugins</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../../src/clioptions.cpp" line="45"/>
        <source>Webcam capture application.</source>
        <translation>Aplicación de captura para la webcam.</translation>
    </message>
    <message>
        <location filename="../../src/clioptions.cpp" line="48"/>
        <source>Load settings from PATH. If PATH is empty, load configs from application directory.</source>
        <translation>Cargar configuraciones desde RUTA. Si RUTA está vacío, carga las configuraciones desde el directorio de la aplicación.</translation>
    </message>
    <message>
        <location filename="../../src/clioptions.cpp" line="50"/>
        <source>PATH</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/clioptions.cpp" line="54"/>
        <source>Semi-colon separated list of paths to search the Qml interface.</source>
        <translation>Lista de rutas separadas por punto y coma para buscar en la interfaz Qml.</translation>
    </message>
    <message>
        <location filename="../../src/clioptions.cpp" line="56"/>
        <location filename="../../src/clioptions.cpp" line="68"/>
        <location filename="../../src/clioptions.cpp" line="74"/>
        <location filename="../../src/clioptions.cpp" line="80"/>
        <source>PATH1;PATH2;PATH3;...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/clioptions.cpp" line="61"/>
        <source>Search in the specified plugins paths recursively.</source>
        <translation>Busque en las rutas de los plugins especificados recursivamente.</translation>
    </message>
    <message>
        <location filename="../../src/clioptions.cpp" line="66"/>
        <source>Semi-colon separated list of paths to search for plugins.</source>
        <translation>Lista de rutas separadas por dos puntos para buscar plugins.</translation>
    </message>
    <message>
        <location filename="../../src/clioptions.cpp" line="72"/>
        <source>Semi-colon separated list of paths to avoid loading.</source>
        <translation>Lista de rutas separadas por dos puntos para evitar la carga.</translation>
    </message>
    <message>
        <location filename="../../src/clioptions.cpp" line="78"/>
        <source>Semi-colon separated list of paths to search for virtual camera driver</source>
        <translation>Lista de rutas separadas por punto y coma para buscar el controlador de la cámara virtual</translation>
    </message>
</context>
<context>
    <name>RecordBar</name>
    <message>
        <location filename="../qml/RecordBar.qml" line="101"/>
        <source>Search format...</source>
        <translation>Buscar formato...</translation>
    </message>
</context>
<context>
    <name>RecordConfig</name>
    <message>
        <location filename="../qml/RecordConfig.qml" line="71"/>
        <source>Video %1.%2</source>
        <translation>Vídeo %1.%2</translation>
    </message>
    <message>
        <location filename="../qml/RecordConfig.qml" line="88"/>
        <source>Stop recording video</source>
        <translation>Detener la grabación de vídeo</translation>
    </message>
    <message>
        <location filename="../qml/RecordConfig.qml" line="91"/>
        <location filename="../qml/RecordConfig.qml" line="128"/>
        <source>Start recording video</source>
        <translation>Iniciar la grabación de vídeo</translation>
    </message>
    <message>
        <location filename="../qml/RecordConfig.qml" line="99"/>
        <source>Description</source>
        <translation>Descripción</translation>
    </message>
    <message>
        <location filename="../qml/RecordConfig.qml" line="106"/>
        <source>Insert format description</source>
        <translation>Ingresar la descripción del formato</translation>
    </message>
    <message>
        <location filename="../qml/RecordConfig.qml" line="193"/>
        <source>Save video as...</source>
        <translation>Guardar vídeo como...</translation>
    </message>
</context>
<context>
    <name>Recording</name>
    <message>
        <location filename="../../src/recording.cpp" line="594"/>
        <source>Audio</source>
        <translation>Audio</translation>
    </message>
    <message>
        <location filename="../../src/recording.cpp" line="595"/>
        <source>Video</source>
        <translation>Vídeo</translation>
    </message>
    <message>
        <location filename="../../src/recording.cpp" line="596"/>
        <source>Subtitle</source>
        <translation>Subtítulo</translation>
    </message>
    <message>
        <location filename="../../src/recording.cpp" line="661"/>
        <location filename="../../src/recording.cpp" line="827"/>
        <source>audio</source>
        <translation>audio</translation>
    </message>
    <message>
        <location filename="../../src/recording.cpp" line="662"/>
        <location filename="../../src/recording.cpp" line="828"/>
        <source>video</source>
        <translation>vídeo</translation>
    </message>
    <message>
        <location filename="../../src/recording.cpp" line="663"/>
        <location filename="../../src/recording.cpp" line="829"/>
        <source>subtitle</source>
        <translation>subtítulo</translation>
    </message>
</context>
<context>
    <name>StreamOptions</name>
    <message>
        <location filename="../../../libAvKys/Plugins/MultiSink/share/qml/StreamOptions.qml" line="28"/>
        <source>Stream #%1 (%2)</source>
        <translation>Flujo #%1 (%2)</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/MultiSink/share/qml/StreamOptions.qml" line="29"/>
        <source>Stream #%1</source>
        <translation>Flujo #%1</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/MultiSink/share/qml/StreamOptions.qml" line="64"/>
        <source>Codec</source>
        <translation>Códec</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/MultiSink/share/qml/StreamOptions.qml" line="85"/>
        <source>Bitrate</source>
        <translation>Bitrate</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/MultiSink/share/qml/StreamOptions.qml" line="105"/>
        <source>GOP</source>
        <translation>GOP</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/MultiSink/share/qml/StreamOptions.qml" line="110"/>
        <source>Separation between keyframes</source>
        <translation>Separación entre fotogramas clave</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/MultiSink/share/qml/StreamOptions.qml" line="126"/>
        <source>Advanced Codec Options</source>
        <translation>Opciones avanzadas de códec</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/MultiSink/share/qml/StreamOptions.qml" line="150"/>
        <source>Size of the audio (bits) / duration (seconds)</source>
        <translation>Tamaño del audio (bits) / duración (segundos)</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/MultiSink/share/qml/StreamOptions.qml" line="171"/>
        <source>Size of the video (bits) / duration (seconds)</source>
        <translation>Tamaño del vídeo (bits) / duración (segundos)</translation>
    </message>
</context>
<context>
    <name>UpdatesConfig</name>
    <message>
        <location filename="../qml/UpdatesConfig.qml" line="68"/>
        <source>Notify about new versions</source>
        <translation>Notificar sobre nuevas versiones</translation>
    </message>
    <message>
        <location filename="../qml/UpdatesConfig.qml" line="82"/>
        <source>Check new versions</source>
        <translation>Buscar nuevas versiones</translation>
    </message>
    <message>
        <location filename="../qml/UpdatesConfig.qml" line="90"/>
        <source>Daily</source>
        <translation>Diario</translation>
    </message>
    <message>
        <location filename="../qml/UpdatesConfig.qml" line="94"/>
        <source>Every two days</source>
        <translation>Cada dos días</translation>
    </message>
    <message>
        <location filename="../qml/UpdatesConfig.qml" line="98"/>
        <source>Weekly</source>
        <translation>Semanal</translation>
    </message>
    <message>
        <location filename="../qml/UpdatesConfig.qml" line="102"/>
        <source>Every two weeks</source>
        <translation>Cada dos semanas</translation>
    </message>
    <message>
        <location filename="../qml/UpdatesConfig.qml" line="106"/>
        <source>Monthly</source>
        <translation>Mensual</translation>
    </message>
    <message>
        <location filename="../qml/UpdatesConfig.qml" line="110"/>
        <source>Never</source>
        <translation>Nunca</translation>
    </message>
    <message>
        <location filename="../qml/UpdatesConfig.qml" line="121"/>
        <source>Last updated</source>
        <translation>Última actualización</translation>
    </message>
    <message>
        <location filename="../qml/UpdatesConfig.qml" line="142"/>
        <source>Your version of %1 is outdated. Latest version is &lt;b&gt;%2&lt;/b&gt;.</source>
        <translation>Su versión de %1 está desactualizada. La última versión es &lt;b&gt;%2&lt;/b&gt;.</translation>
    </message>
    <message>
        <location filename="../qml/UpdatesConfig.qml" line="148"/>
        <source>Upgrade Now!</source>
        <translation>¡Actualizar ahora!</translation>
    </message>
    <message>
        <location filename="../qml/UpdatesConfig.qml" line="163"/>
        <source>Thanks for using a &lt;b&gt;development version&lt;/b&gt;!&lt;br /&gt;It will be very helpful if you can report any bug and suggestions you have.</source>
        <translation>¡Gracias por usar un &lt;b&gt;versión de desarrollo&lt;/b&gt;!&lt;br /&gt;Será muy útil si puede informar de cualquier error y sugerencia que tenga.</translation>
    </message>
    <message>
        <location filename="../qml/UpdatesConfig.qml" line="168"/>
        <source>Report a Bug</source>
        <translation>Reportar un error</translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <location filename="../qml/main.qml" line="172"/>
        <source>Recording</source>
        <translation>Grabando</translation>
    </message>
    <message>
        <location filename="../qml/main.qml" line="111"/>
        <location filename="../qml/main.qml" line="618"/>
        <source>Play</source>
        <translation>Reproducir</translation>
    </message>
    <message>
        <location filename="../qml/main.qml" line="652"/>
        <source>Take a photo</source>
        <translation>Tomar una foto</translation>
    </message>
    <message>
        <location filename="../qml/main.qml" line="252"/>
        <source>Picture %1.%2</source>
        <translation>Imagen %1.%2</translation>
    </message>
    <message>
        <location filename="../qml/main.qml" line="71"/>
        <source>New version available!</source>
        <translation>¡Nueva versión disponible!</translation>
    </message>
    <message>
        <location filename="../qml/main.qml" line="72"/>
        <source>Download %1 %2 NOW!</source>
        <translation>Descargar %1 %2 ¡AHORA!</translation>
    </message>
    <message>
        <location filename="../qml/main.qml" line="107"/>
        <source>Stop</source>
        <translation>Detener</translation>
    </message>
    <message>
        <location filename="../qml/main.qml" line="572"/>
        <source>Go back</source>
        <translation>Regresar</translation>
    </message>
    <message>
        <location filename="../qml/main.qml" line="626"/>
        <source>Configure sources</source>
        <translation>Configurar fuentes</translation>
    </message>
    <message>
        <location filename="../qml/main.qml" line="639"/>
        <source>Configure audio</source>
        <translation>Configurar audio</translation>
    </message>
    <message>
        <location filename="../qml/main.qml" line="666"/>
        <source>Record video</source>
        <translation>Grabar vídeo</translation>
    </message>
    <message>
        <location filename="../qml/main.qml" line="680"/>
        <source>Configure Effects</source>
        <translation>Configurar efectos</translation>
    </message>
    <message>
        <location filename="../qml/main.qml" line="693"/>
        <source>Preferences</source>
        <translation>Preferencias</translation>
    </message>
    <message>
        <location filename="../qml/main.qml" line="706"/>
        <source>About</source>
        <translation>Acerca de</translation>
    </message>
    <message>
        <location filename="../qml/main.qml" line="261"/>
        <source>Save photo as...</source>
        <translation>Guardar foto como...</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Aging/share/qml/main.qml" line="40"/>
        <source>Number of scratches</source>
        <translation>Número de rayas</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Aging/share/qml/main.qml" line="62"/>
        <source>Add dust</source>
        <translation>Añadir polvo</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Blur/share/qml/main.qml" line="40"/>
        <location filename="../../../libAvKys/Plugins/ColorFilter/share/qml/main.qml" line="77"/>
        <location filename="../../../libAvKys/Plugins/ColorReplace/share/qml/main.qml" line="93"/>
        <location filename="../../../libAvKys/Plugins/Denoise/share/qml/main.qml" line="43"/>
        <location filename="../../../libAvKys/Plugins/OilPaint/share/qml/main.qml" line="28"/>
        <source>Radius</source>
        <translation>Ratio</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Cartoon/share/qml/main.qml" line="85"/>
        <location filename="../../../libAvKys/Plugins/Fire/share/qml/main.qml" line="256"/>
        <source>N° of colors</source>
        <translation>N° de colores</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Cartoon/share/qml/main.qml" line="107"/>
        <source>Color difference</source>
        <translation>Diferencia de color</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Cartoon/share/qml/main.qml" line="128"/>
        <source>Show edges</source>
        <translation>Mostrar bordes</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Cartoon/share/qml/main.qml" line="141"/>
        <source>Threshold low</source>
        <translation>Umbral bajo</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Cartoon/share/qml/main.qml" line="166"/>
        <source>Threshold high</source>
        <translation>Umbral alto</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Cartoon/share/qml/main.qml" line="190"/>
        <source>Line color</source>
        <translation>Color de línea</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Cartoon/share/qml/main.qml" line="205"/>
        <location filename="../../../libAvKys/Plugins/FaceDetect/share/qml/main.qml" line="215"/>
        <source>Scan block</source>
        <translation>Analizar bloque</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Cartoon/share/qml/main.qml" line="195"/>
        <location filename="../../../libAvKys/Plugins/Radioactive/share/qml/main.qml" line="163"/>
        <source>Choose a color</source>
        <translation>Elija un color</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/ChangeHSL/share/qml/main.qml" line="36"/>
        <location filename="../../../libAvKys/Plugins/ColorTransform/share/qml/main.qml" line="36"/>
        <location filename="../../../libAvKys/Plugins/MatrixTransform/share/qml/main.qml" line="35"/>
        <source>Transform matrix</source>
        <translation>Matriz de transformación</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Charify/share/qml/main.qml" line="63"/>
        <location filename="../../../libAvKys/Plugins/Fire/share/qml/main.qml" line="72"/>
        <location filename="../../../libAvKys/Plugins/Hypnotic/share/qml/main.qml" line="52"/>
        <location filename="../../../libAvKys/Plugins/Radioactive/share/qml/main.qml" line="63"/>
        <location filename="../../../libAvKys/Plugins/Ripple/share/qml/main.qml" line="41"/>
        <source>Mode</source>
        <translation>Modo</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Charify/share/qml/main.qml" line="73"/>
        <source>Natural</source>
        <translation>Natural</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Charify/share/qml/main.qml" line="77"/>
        <source>Fixed</source>
        <translation>Fijado</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Charify/share/qml/main.qml" line="86"/>
        <location filename="../../../libAvKys/Plugins/Matrix/share/qml/main.qml" line="76"/>
        <source>Symbols</source>
        <translation>Símbolos</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Charify/share/qml/main.qml" line="96"/>
        <location filename="../../../libAvKys/Plugins/Matrix/share/qml/main.qml" line="85"/>
        <source>Font</source>
        <translation>Fuente</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Charify/share/qml/main.qml" line="107"/>
        <location filename="../../../libAvKys/Plugins/ColorTap/share/qml/main.qml" line="122"/>
        <location filename="../../../libAvKys/Plugins/FaceDetect/share/qml/main.qml" line="526"/>
        <location filename="../../../libAvKys/Plugins/Halftone/share/qml/main.qml" line="140"/>
        <source>Search</source>
        <translation>Buscar</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Charify/share/qml/main.qml" line="115"/>
        <location filename="../../../libAvKys/Plugins/Matrix/share/qml/main.qml" line="104"/>
        <source>Hinting</source>
        <translation>Sugerencia</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Charify/share/qml/main.qml" line="125"/>
        <location filename="../../../libAvKys/Plugins/Charify/share/qml/main.qml" line="156"/>
        <location filename="../../../libAvKys/Plugins/Matrix/share/qml/main.qml" line="114"/>
        <location filename="../../../libAvKys/Plugins/Matrix/share/qml/main.qml" line="145"/>
        <source>Default</source>
        <translation>Predeterminado</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Charify/share/qml/main.qml" line="129"/>
        <location filename="../../../libAvKys/Plugins/Matrix/share/qml/main.qml" line="118"/>
        <source>No hinting</source>
        <translation>Sin sugerencia</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Charify/share/qml/main.qml" line="133"/>
        <location filename="../../../libAvKys/Plugins/Matrix/share/qml/main.qml" line="122"/>
        <source>Vertical hinting</source>
        <translation>Sugerencia vertical</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Charify/share/qml/main.qml" line="137"/>
        <location filename="../../../libAvKys/Plugins/Matrix/share/qml/main.qml" line="126"/>
        <source>Full hinting</source>
        <translation>Sugerencia completa</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Charify/share/qml/main.qml" line="146"/>
        <location filename="../../../libAvKys/Plugins/Matrix/share/qml/main.qml" line="135"/>
        <source>Style</source>
        <translation>Estilo</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Charify/share/qml/main.qml" line="160"/>
        <location filename="../../../libAvKys/Plugins/Matrix/share/qml/main.qml" line="149"/>
        <source>Bitmap</source>
        <translation>Mapa de bits</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Charify/share/qml/main.qml" line="164"/>
        <location filename="../../../libAvKys/Plugins/Matrix/share/qml/main.qml" line="153"/>
        <source>Device</source>
        <translation>Dispositivo</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Charify/share/qml/main.qml" line="168"/>
        <location filename="../../../libAvKys/Plugins/Matrix/share/qml/main.qml" line="157"/>
        <source>Outline</source>
        <translation>Contorno</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Charify/share/qml/main.qml" line="172"/>
        <location filename="../../../libAvKys/Plugins/Matrix/share/qml/main.qml" line="161"/>
        <source>Force outline</source>
        <translation>Forzar contorno</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Charify/share/qml/main.qml" line="176"/>
        <location filename="../../../libAvKys/Plugins/Matrix/share/qml/main.qml" line="165"/>
        <source>Match</source>
        <translation>Coincidir</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Charify/share/qml/main.qml" line="180"/>
        <location filename="../../../libAvKys/Plugins/Matrix/share/qml/main.qml" line="169"/>
        <source>Quality</source>
        <translation>Calidad</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Charify/share/qml/main.qml" line="184"/>
        <location filename="../../../libAvKys/Plugins/Matrix/share/qml/main.qml" line="173"/>
        <source>Antialias</source>
        <translation>Antialias</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Charify/share/qml/main.qml" line="188"/>
        <location filename="../../../libAvKys/Plugins/Matrix/share/qml/main.qml" line="177"/>
        <source>No antialias</source>
        <translation>Sin antialias</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Charify/share/qml/main.qml" line="192"/>
        <location filename="../../../libAvKys/Plugins/Matrix/share/qml/main.qml" line="181"/>
        <source>Compatible with OpenGL</source>
        <translation>Compatible con OpenGL</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Charify/share/qml/main.qml" line="196"/>
        <location filename="../../../libAvKys/Plugins/Matrix/share/qml/main.qml" line="185"/>
        <source>Force integer metrics</source>
        <translation>Forzar métricas enteras</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Charify/share/qml/main.qml" line="200"/>
        <location filename="../../../libAvKys/Plugins/Matrix/share/qml/main.qml" line="189"/>
        <source>No subpixel antialias</source>
        <translation>Sin antialias de subpíxel</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Charify/share/qml/main.qml" line="204"/>
        <location filename="../../../libAvKys/Plugins/Matrix/share/qml/main.qml" line="193"/>
        <source>No font merging</source>
        <translation>Sin fusión de fuentes</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Charify/share/qml/main.qml" line="213"/>
        <location filename="../../../libAvKys/Plugins/Matrix/share/qml/main.qml" line="212"/>
        <source>Foreground color</source>
        <translation>Color de primer plano</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Charify/share/qml/main.qml" line="224"/>
        <location filename="../../../libAvKys/Plugins/Matrix/share/qml/main.qml" line="222"/>
        <location filename="../../../libAvKys/Plugins/Wave/share/qml/main.qml" line="138"/>
        <source>Background color</source>
        <translation>Color de fondo</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Charify/share/qml/main.qml" line="235"/>
        <source>Reversed</source>
        <translation>Invertido</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Charify/share/qml/main.qml" line="245"/>
        <location filename="../../../libAvKys/Plugins/Matrix/share/qml/main.qml" line="294"/>
        <source>Please choose a font</source>
        <translation>Por favor elija una fuente</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Charify/share/qml/main.qml" line="217"/>
        <location filename="../../../libAvKys/Plugins/Matrix/share/qml/main.qml" line="216"/>
        <source>Choose the foreground color</source>
        <translation>Elija el color de primer plano</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Charify/share/qml/main.qml" line="228"/>
        <location filename="../../../libAvKys/Plugins/Matrix/share/qml/main.qml" line="226"/>
        <location filename="../../../libAvKys/Plugins/Wave/share/qml/main.qml" line="142"/>
        <source>Choose the background color</source>
        <translation>Elija el color de fondo</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Cinema/share/qml/main.qml" line="61"/>
        <location filename="../../../libAvKys/Plugins/Dice/share/qml/main.qml" line="39"/>
        <source>Size</source>
        <translation>Tamaño</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Cinema/share/qml/main.qml" line="84"/>
        <location filename="../../../libAvKys/Plugins/ColorFilter/share/qml/main.qml" line="60"/>
        <location filename="../../../libAvKys/Plugins/Life/share/qml/main.qml" line="64"/>
        <location filename="../../../libAvKys/Plugins/Vignette/share/qml/main.qml" line="69"/>
        <source>Color</source>
        <translation>Color</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Cinema/share/qml/main.qml" line="88"/>
        <source>Choose the strips color</source>
        <translation>Elija el color de las tiras</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/ColorFilter/share/qml/main.qml" line="100"/>
        <location filename="../../../libAvKys/Plugins/FalseColor/share/qml/main.qml" line="102"/>
        <location filename="../../../libAvKys/Plugins/Fire/share/qml/main.qml" line="83"/>
        <source>Soft</source>
        <translation>Suave</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/ColorFilter/share/qml/main.qml" line="64"/>
        <source>Select the color to filter</source>
        <translation>Seleccione el color para filtrar</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/ColorReplace/share/qml/main.qml" line="60"/>
        <source>Old color</source>
        <translation>Color viejo</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/ColorReplace/share/qml/main.qml" line="76"/>
        <source>New color</source>
        <translation>Color nuevo</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/ColorReplace/share/qml/main.qml" line="64"/>
        <source>Select the color to replace</source>
        <translation>Seleccione el color para reemplazar</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/ColorReplace/share/qml/main.qml" line="80"/>
        <source>Select the new color</source>
        <translation>Seleccione el nuevo color</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/ColorTap/share/qml/main.qml" line="37"/>
        <location filename="../../../libAvKys/Plugins/FalseColor/share/qml/main.qml" line="75"/>
        <source>Color table</source>
        <translation>Tabla de colores</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/ColorTap/share/qml/main.qml" line="46"/>
        <source>Base</source>
        <translation>Base</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/ColorTap/share/qml/main.qml" line="50"/>
        <source>Metal</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/ColorTap/share/qml/main.qml" line="54"/>
        <source>Heat</source>
        <translation>Intensidad</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/ColorTap/share/qml/main.qml" line="58"/>
        <source>Old Photo</source>
        <translation>Foto vieja</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/ColorTap/share/qml/main.qml" line="62"/>
        <source>Red &amp; Green</source>
        <translation>Rojo y verde</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/ColorTap/share/qml/main.qml" line="66"/>
        <source>Sepia</source>
        <translation>Sepia</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/ColorTap/share/qml/main.qml" line="70"/>
        <source>X-Pro</source>
        <translation>X-Pro</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/ColorTap/share/qml/main.qml" line="74"/>
        <source>X-Ray</source>
        <translation>Rayos-X</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/ColorTap/share/qml/main.qml" line="78"/>
        <source>Yellow &amp; Blue</source>
        <translation>Amarillo y azul</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/ColorTap/share/qml/main.qml" line="82"/>
        <location filename="../../../libAvKys/Plugins/FaceDetect/share/qml/main.qml" line="484"/>
        <location filename="../../../libAvKys/Plugins/Halftone/share/qml/main.qml" line="101"/>
        <source>Custom</source>
        <translation>Personalizado</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/ColorTap/share/qml/main.qml" line="103"/>
        <source>16x16 bitmap...</source>
        <translation>16x16 mapa de bits...</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/ColorTap/share/qml/main.qml" line="131"/>
        <location filename="../../../libAvKys/Plugins/FaceDetect/share/qml/main.qml" line="563"/>
        <location filename="../../../libAvKys/Plugins/Halftone/share/qml/main.qml" line="202"/>
        <source>Please choose an image file</source>
        <translation>Por favor elija un archivo de imagen</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Convolve/share/qml/main.qml" line="47"/>
        <source>Convolve matrix</source>
        <translation>Matriz de implicación</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Convolve/share/qml/main.qml" line="153"/>
        <location filename="../../../libAvKys/Plugins/Denoise/share/qml/main.qml" line="64"/>
        <location filename="../../../libAvKys/Plugins/Emboss/share/qml/main.qml" line="29"/>
        <location filename="../../../libAvKys/Plugins/PrimariesColors/share/qml/main.qml" line="28"/>
        <source>Factor</source>
        <translation>Factor</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Convolve/share/qml/main.qml" line="167"/>
        <location filename="../../../libAvKys/Plugins/Emboss/share/qml/main.qml" line="43"/>
        <source>Bias</source>
        <translation>Predisposición</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/DelayGrab/share/qml/main.qml" line="42"/>
        <source>Grab mode</source>
        <translation>Modo de agarre</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/DelayGrab/share/qml/main.qml" line="52"/>
        <source>Random square</source>
        <translation>Cuadrado aleatorio</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/DelayGrab/share/qml/main.qml" line="56"/>
        <source>Vertical increase</source>
        <translation>Aumento vertical</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/DelayGrab/share/qml/main.qml" line="60"/>
        <source>Horizontal increase</source>
        <translation>Aumento horizontal</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/DelayGrab/share/qml/main.qml" line="64"/>
        <source>Rings increase</source>
        <translation>Aumento de anillos</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/DelayGrab/share/qml/main.qml" line="73"/>
        <location filename="../../../libAvKys/Plugins/Pixelate/share/qml/main.qml" line="41"/>
        <source>Block size</source>
        <translation>Tamaño del bloque</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/DelayGrab/share/qml/main.qml" line="86"/>
        <location filename="../../../libAvKys/Plugins/FrameOverlap/share/qml/main.qml" line="29"/>
        <location filename="../../../libAvKys/Plugins/Nervous/share/qml/main.qml" line="28"/>
        <location filename="../../../libAvKys/Plugins/Quark/share/qml/main.qml" line="28"/>
        <location filename="../../../libAvKys/Plugins/Warhol/share/qml/main.qml" line="28"/>
        <source>N° of frames</source>
        <translation>N° de cuadros</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Denoise/share/qml/main.qml" line="78"/>
        <source>Mu</source>
        <translation>Mu</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Denoise/share/qml/main.qml" line="92"/>
        <source>Sigma</source>
        <translation>Sigma</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/DesktopCapture/share/qml/main.qml" line="48"/>
        <source>Frame rate</source>
        <translation>Cuadros por segundo</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Distort/share/qml/main.qml" line="29"/>
        <location filename="../../../libAvKys/Plugins/Ripple/share/qml/main.qml" line="64"/>
        <location filename="../../../libAvKys/Plugins/Wave/share/qml/main.qml" line="70"/>
        <source>Amplitude</source>
        <translation>Amplitud</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Distort/share/qml/main.qml" line="43"/>
        <location filename="../../../libAvKys/Plugins/Wave/share/qml/main.qml" line="93"/>
        <source>Frequency</source>
        <translation>Frecuencia</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Distort/share/qml/main.qml" line="57"/>
        <source>Grid size</source>
        <translation>Tamaño de la cuadrícula</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Dizzy/share/qml/main.qml" line="49"/>
        <source>Speed</source>
        <translation>Velocidad</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Dizzy/share/qml/main.qml" line="74"/>
        <source>Zoom rate</source>
        <translation>Tasa de zoom</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Dizzy/share/qml/main.qml" line="97"/>
        <source>Strength</source>
        <translation>Fuerza</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Edge/share/qml/main.qml" line="44"/>
        <source>Canny mode</source>
        <translation>Modo Canny</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Edge/share/qml/main.qml" line="57"/>
        <source>Lower Canny threshold</source>
        <translation>Umbral inferior de Canny</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Edge/share/qml/main.qml" line="82"/>
        <source>Higger Canny threshold</source>
        <translation>Umbral superior de Canny</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Edge/share/qml/main.qml" line="107"/>
        <source>Equalize</source>
        <translation>Igualar</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Edge/share/qml/main.qml" line="119"/>
        <source>Invert</source>
        <translation>Invertir</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/FaceDetect/share/qml/main.qml" line="111"/>
        <source>Haar file</source>
        <translation>Archivo Haar</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/FaceDetect/share/qml/main.qml" line="121"/>
        <source>Eye</source>
        <translation>Vista</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/FaceDetect/share/qml/main.qml" line="125"/>
        <source>Eye glasses</source>
        <translation>Anteojos</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/FaceDetect/share/qml/main.qml" line="129"/>
        <source>Frontal face alternative 1</source>
        <translation>Alternativa de cara frontal 1</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/FaceDetect/share/qml/main.qml" line="133"/>
        <source>Frontal face alternative 2</source>
        <translation>Alternativa de cara frontal 2</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/FaceDetect/share/qml/main.qml" line="137"/>
        <source>Frontal face alternative 3</source>
        <translation>Alternativa de cara frontal 3</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/FaceDetect/share/qml/main.qml" line="141"/>
        <source>Frontal face default</source>
        <translation>Cara frontal predeterminada</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/FaceDetect/share/qml/main.qml" line="145"/>
        <source>Full body</source>
        <translation>Cuerpo completo</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/FaceDetect/share/qml/main.qml" line="149"/>
        <source>Left Eye 1</source>
        <translation>Ojo izquierdo 1</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/FaceDetect/share/qml/main.qml" line="153"/>
        <source>Lower body</source>
        <translation>Cuerpo inferior</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/FaceDetect/share/qml/main.qml" line="157"/>
        <source>Eye pair big</source>
        <translation>Par de ojos grandes</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/FaceDetect/share/qml/main.qml" line="161"/>
        <source>Eye pair small</source>
        <translation>Par de ojos pequeños</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/FaceDetect/share/qml/main.qml" line="165"/>
        <source>Left ear</source>
        <translation>Oreja izquierda</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/FaceDetect/share/qml/main.qml" line="169"/>
        <source>Left eye 2</source>
        <translation>Ojo izquierdo 2</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/FaceDetect/share/qml/main.qml" line="173"/>
        <source>Mouth</source>
        <translation>Boca</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/FaceDetect/share/qml/main.qml" line="177"/>
        <source>Nose</source>
        <translation>Nariz</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/FaceDetect/share/qml/main.qml" line="181"/>
        <source>Right ear</source>
        <translation>Oreja derecha</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/FaceDetect/share/qml/main.qml" line="185"/>
        <source>Right Eye 1</source>
        <translation>Ojo derecho 1</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/FaceDetect/share/qml/main.qml" line="189"/>
        <source>Upper body 1</source>
        <translation>Parte superior del cuerpo 1</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/FaceDetect/share/qml/main.qml" line="193"/>
        <source>Profile face</source>
        <translation>Cara de perfil</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/FaceDetect/share/qml/main.qml" line="197"/>
        <source>Right eye 2</source>
        <translation>Ojo derecho 2</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/FaceDetect/share/qml/main.qml" line="201"/>
        <source>Smile</source>
        <translation>Sonrisa</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/FaceDetect/share/qml/main.qml" line="205"/>
        <source>Upper body</source>
        <translation>Parte superior del cuerpo</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/FaceDetect/share/qml/main.qml" line="229"/>
        <source>Marker type</source>
        <translation>Tipo de marcador</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/FaceDetect/share/qml/main.qml" line="239"/>
        <source>Rectangle</source>
        <translation>Rectángulo</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/FaceDetect/share/qml/main.qml" line="243"/>
        <source>Ellipse</source>
        <translation>Elipse</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/FaceDetect/share/qml/main.qml" line="247"/>
        <source>Image</source>
        <translation>Imagen</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/FaceDetect/share/qml/main.qml" line="251"/>
        <source>Pixelate</source>
        <translation>Pixelado</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/FaceDetect/share/qml/main.qml" line="255"/>
        <location filename="../../../libAvKys/Plugins/Fire/share/qml/main.qml" line="136"/>
        <location filename="../../../libAvKys/Plugins/Radioactive/share/qml/main.qml" line="94"/>
        <source>Blur</source>
        <translation>Difuminar</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/FaceDetect/share/qml/main.qml" line="265"/>
        <source>Marker style</source>
        <translation>Estilo de marcador</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/FaceDetect/share/qml/main.qml" line="275"/>
        <source>Solid</source>
        <translation>Sólido</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/FaceDetect/share/qml/main.qml" line="279"/>
        <source>Dash</source>
        <translation>Guión</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/FaceDetect/share/qml/main.qml" line="283"/>
        <source>Dot</source>
        <translation>Punto</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/FaceDetect/share/qml/main.qml" line="287"/>
        <source>Dash dot</source>
        <translation>Punto y guión</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/FaceDetect/share/qml/main.qml" line="291"/>
        <source>Dash dot dot</source>
        <translation>Punto, guión y guión</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/FaceDetect/share/qml/main.qml" line="301"/>
        <source>Marker color</source>
        <translation>Marcador de color</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/FaceDetect/share/qml/main.qml" line="313"/>
        <source>Marker width</source>
        <translation>Ancho del marcador</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/FaceDetect/share/qml/main.qml" line="327"/>
        <source>Masks</source>
        <translation>Máscaras</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/FaceDetect/share/qml/main.qml" line="336"/>
        <source>Angel</source>
        <translation>Ángel</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/FaceDetect/share/qml/main.qml" line="340"/>
        <source>Bear</source>
        <translation>Oso</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/FaceDetect/share/qml/main.qml" line="344"/>
        <source>Beaver</source>
        <translation>Castor</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/FaceDetect/share/qml/main.qml" line="348"/>
        <source>Cat</source>
        <translation>Gato</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/FaceDetect/share/qml/main.qml" line="352"/>
        <source>Chicken</source>
        <translation>Pollo</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/FaceDetect/share/qml/main.qml" line="356"/>
        <source>Cow</source>
        <translation>Vaca</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/FaceDetect/share/qml/main.qml" line="360"/>
        <source>Devil</source>
        <translation>Diablo</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/FaceDetect/share/qml/main.qml" line="364"/>
        <source>Dog</source>
        <translation>Perro</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/FaceDetect/share/qml/main.qml" line="368"/>
        <source>Dalmatian dog</source>
        <translation>Perro dálmata</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/FaceDetect/share/qml/main.qml" line="372"/>
        <source>Happy dog</source>
        <translation>Perro feliz</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/FaceDetect/share/qml/main.qml" line="376"/>
        <source>Dragon</source>
        <translation>Dragón</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/FaceDetect/share/qml/main.qml" line="380"/>
        <source>Elephant 1</source>
        <translation>Elefante 1</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/FaceDetect/share/qml/main.qml" line="384"/>
        <source>Elephant 2</source>
        <translation>Elefante 2</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/FaceDetect/share/qml/main.qml" line="388"/>
        <source>Elk</source>
        <translation>Alce</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/FaceDetect/share/qml/main.qml" line="392"/>
        <source>Frog</source>
        <translation>Rana</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/FaceDetect/share/qml/main.qml" line="396"/>
        <source>Ghost</source>
        <translation>Fantasma</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/FaceDetect/share/qml/main.qml" line="400"/>
        <source>Giraffe</source>
        <translation>Jirafa</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/FaceDetect/share/qml/main.qml" line="404"/>
        <source>Gnu</source>
        <translation>Ñu</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/FaceDetect/share/qml/main.qml" line="408"/>
        <source>Goat</source>
        <translation>Cabra</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/FaceDetect/share/qml/main.qml" line="412"/>
        <source>Hippo</source>
        <translation>Hipopótamo</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/FaceDetect/share/qml/main.qml" line="416"/>
        <source>Horse</source>
        <translation>Caballo</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/FaceDetect/share/qml/main.qml" line="420"/>
        <source>Gray horse</source>
        <translation>Caballo gris</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/FaceDetect/share/qml/main.qml" line="424"/>
        <source>Koala</source>
        <translation>Coala</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/FaceDetect/share/qml/main.qml" line="428"/>
        <source>Monkey</source>
        <translation>Mono</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/FaceDetect/share/qml/main.qml" line="432"/>
        <source>Gray mouse</source>
        <translation>Ratón gris</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/FaceDetect/share/qml/main.qml" line="436"/>
        <source>White mouse</source>
        <translation>Ratón blanco</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/FaceDetect/share/qml/main.qml" line="440"/>
        <source>Panda</source>
        <translation>Panda</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/FaceDetect/share/qml/main.qml" line="444"/>
        <source>Penguin</source>
        <translation>Pingüino</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/FaceDetect/share/qml/main.qml" line="448"/>
        <source>Pumpkin 1</source>
        <translation>Calabaza 1</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/FaceDetect/share/qml/main.qml" line="452"/>
        <source>Pumpkin 2</source>
        <translation>Calabaza 2</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/FaceDetect/share/qml/main.qml" line="456"/>
        <source>Raccoon</source>
        <translation>Mapache</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/FaceDetect/share/qml/main.qml" line="460"/>
        <source>Rhino</source>
        <translation>Rinoceronte</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/FaceDetect/share/qml/main.qml" line="464"/>
        <source>Sheep</source>
        <translation>Oveja</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/FaceDetect/share/qml/main.qml" line="468"/>
        <source>Skull 1</source>
        <translation>Cráneo 1</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/FaceDetect/share/qml/main.qml" line="472"/>
        <source>Skull 2</source>
        <translation>Cráneo 2</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/FaceDetect/share/qml/main.qml" line="476"/>
        <source>Triceratops</source>
        <translation>Triceratops</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/FaceDetect/share/qml/main.qml" line="480"/>
        <source>Zebra</source>
        <translation>Cebra</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/FaceDetect/share/qml/main.qml" line="493"/>
        <source>Marker picture</source>
        <translation>Imagen de marcador</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/FaceDetect/share/qml/main.qml" line="507"/>
        <source>Replace face with this picture.</source>
        <translation>Reemplazar la cara con esta imagen.</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/FaceDetect/share/qml/main.qml" line="535"/>
        <source>Pixel grid size</source>
        <translation>Tamaño de cuadrícula de píxel</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/FaceDetect/share/qml/main.qml" line="549"/>
        <source>Blur radius</source>
        <translation>Ratio de desenfoque</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/FaceDetect/share/qml/main.qml" line="305"/>
        <source>Select marker color</source>
        <translation>Seleccionar el color del marcador</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Fire/share/qml/main.qml" line="87"/>
        <source>Hard</source>
        <translation>Duro</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Fire/share/qml/main.qml" line="97"/>
        <source>Cooling</source>
        <translation>Enfriamiento</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Fire/share/qml/main.qml" line="121"/>
        <source>Dissolve</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Fire/share/qml/main.qml" line="151"/>
        <location filename="../../../libAvKys/Plugins/Radioactive/share/qml/main.qml" line="107"/>
        <source>Zoom</source>
        <translation>Zoom</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Fire/share/qml/main.qml" line="166"/>
        <location filename="../../../libAvKys/Plugins/Hypnotic/share/qml/main.qml" line="98"/>
        <location filename="../../../libAvKys/Plugins/Life/share/qml/main.qml" line="78"/>
        <location filename="../../../libAvKys/Plugins/Radioactive/share/qml/main.qml" line="120"/>
        <location filename="../../../libAvKys/Plugins/Ripple/share/qml/main.qml" line="90"/>
        <source>Threshold</source>
        <translation>Umbral</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Fire/share/qml/main.qml" line="188"/>
        <location filename="../../../libAvKys/Plugins/Radioactive/share/qml/main.qml" line="133"/>
        <location filename="../../../libAvKys/Plugins/Ripple/share/qml/main.qml" line="103"/>
        <source>Luma threshold</source>
        <translation>Umbral de luz</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Fire/share/qml/main.qml" line="210"/>
        <source>Alpha diff</source>
        <translation>Diferencia alfa</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Fire/share/qml/main.qml" line="234"/>
        <source>Alpha variation</source>
        <translation>Variación alfa</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/FrameOverlap/share/qml/main.qml" line="43"/>
        <source>Stride</source>
        <translation>Paseo</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Halftone/share/qml/main.qml" line="51"/>
        <source>Pattern</source>
        <translation>Patrón</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Halftone/share/qml/main.qml" line="61"/>
        <source>90° Halftone 6x6</source>
        <translation>90° semitono 6x6</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Halftone/share/qml/main.qml" line="65"/>
        <source>Cluster 3</source>
        <translation>Grupo 3</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Halftone/share/qml/main.qml" line="69"/>
        <source>Cluster 4</source>
        <translation>Grupo 4</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Halftone/share/qml/main.qml" line="73"/>
        <source>Cluster 8</source>
        <translation>Grupo 8</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Halftone/share/qml/main.qml" line="77"/>
        <source>Lines 4x4</source>
        <translation>Líneas 4x4</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Halftone/share/qml/main.qml" line="81"/>
        <source>Magic 2x2</source>
        <translation>Mágico 2x2</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Halftone/share/qml/main.qml" line="85"/>
        <source>Magic 4x4</source>
        <translation>Mágico 4x4</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Halftone/share/qml/main.qml" line="89"/>
        <source>Ordered 4x4</source>
        <translation>Ordenado 4x4</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Halftone/share/qml/main.qml" line="93"/>
        <source>Ordered 6x6</source>
        <translation>Ordenado 6x6</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Halftone/share/qml/main.qml" line="97"/>
        <source>Ordered 8x8</source>
        <translation>Ordenado 8x8</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Halftone/share/qml/main.qml" line="120"/>
        <source>pattern bitmap...</source>
        <translation>mapa de bits de patrón...</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Halftone/share/qml/main.qml" line="149"/>
        <source>Pattern size</source>
        <translation>Tamaño del patrón</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Halftone/share/qml/main.qml" line="162"/>
        <source>Lightness</source>
        <translation>Ligereza</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Halftone/share/qml/main.qml" line="175"/>
        <source>Slope</source>
        <translation>Pendiente</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Halftone/share/qml/main.qml" line="188"/>
        <source>Intercept</source>
        <translation>Interceptar</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Hypnotic/share/qml/main.qml" line="63"/>
        <source>Spiral 1</source>
        <translation>Espiral 1</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Hypnotic/share/qml/main.qml" line="67"/>
        <source>Spiral 2</source>
        <translation>Espiral 2</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Hypnotic/share/qml/main.qml" line="71"/>
        <source>Parabola</source>
        <translation>Parábola</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Hypnotic/share/qml/main.qml" line="75"/>
        <source>Horizontal stripe</source>
        <translation>Franja horizontal</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Hypnotic/share/qml/main.qml" line="84"/>
        <source>Speed increment</source>
        <translation>Incremento de velocidad</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Implode/share/qml/main.qml" line="28"/>
        <source>Amount</source>
        <translation>Cantidad</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Life/share/qml/main.qml" line="100"/>
        <source>Luma Threshold</source>
        <translation>Umbral de luma</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Life/share/qml/main.qml" line="68"/>
        <source>Choose the automata color</source>
        <translation>Elija el color del autómata</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Matrix/share/qml/main.qml" line="63"/>
        <source>N° of drops</source>
        <translation>N° de gotas</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Matrix/share/qml/main.qml" line="96"/>
        <source>Select</source>
        <translation>Seleccionar</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Matrix/share/qml/main.qml" line="202"/>
        <source>Cursor color</source>
        <translation>Color del cursor</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Matrix/share/qml/main.qml" line="206"/>
        <source>Choose the cursor color</source>
        <translation>Elija el color del cursor</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Matrix/share/qml/main.qml" line="232"/>
        <source>Min. drop length</source>
        <translation>Min. longitud de gota</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Matrix/share/qml/main.qml" line="245"/>
        <source>Max. drop length</source>
        <translation>Max. longitud de gota</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Matrix/share/qml/main.qml" line="258"/>
        <source>Min. speed</source>
        <translation>Min. velocidad</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Matrix/share/qml/main.qml" line="271"/>
        <source>Max. speed</source>
        <translation>Max. velocidad</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Matrix/share/qml/main.qml" line="284"/>
        <source>Show cursor</source>
        <translation>Mostrar cursor</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/MultiSink/share/qml/main.qml" line="166"/>
        <source>Output format</source>
        <translation>Formato de salida</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/MultiSink/share/qml/main.qml" line="195"/>
        <source>File extensions</source>
        <translation>Extensiones de archivo</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/MultiSink/share/qml/main.qml" line="201"/>
        <source>This output format has not specific extensions</source>
        <translation>Este formato de salida no tiene extensiones específicas</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/MultiSink/share/qml/main.qml" line="207"/>
        <source>Advanced Format Options</source>
        <translation>Opciones avanzadas de formato</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/MultiSrc/share/qml/main.qml" line="119"/>
        <source>Video track</source>
        <translation>Pista de vídeo</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/MultiSrc/share/qml/main.qml" line="132"/>
        <source>Audio track</source>
        <translation>Pista de audio</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/MultiSrc/share/qml/main.qml" line="145"/>
        <source>Subtitles track</source>
        <translation>Pista de subtítulos</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Nervous/share/qml/main.qml" line="41"/>
        <source>Simple</source>
        <translation>Sencillo</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Photocopy/share/qml/main.qml" line="28"/>
        <source>Brightness</source>
        <translation>Brillo</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Photocopy/share/qml/main.qml" line="41"/>
        <source>Contrast</source>
        <translation>Contraste</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Radioactive/share/qml/main.qml" line="73"/>
        <source>Soft normal</source>
        <translation>Suave normal</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Radioactive/share/qml/main.qml" line="77"/>
        <source>Hard normal</source>
        <translation>Duro normal</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Radioactive/share/qml/main.qml" line="81"/>
        <source>Soft color</source>
        <translation>Color suave</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Radioactive/share/qml/main.qml" line="85"/>
        <source>Hard color</source>
        <translation>Color duro</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Radioactive/share/qml/main.qml" line="146"/>
        <source>Alpha differential</source>
        <translation>Diferencial alfa</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Radioactive/share/qml/main.qml" line="159"/>
        <source>Radiation color</source>
        <translation>Color de radiación</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Ripple/share/qml/main.qml" line="51"/>
        <source>Motion detect</source>
        <translation>Detección de movimiento</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Ripple/share/qml/main.qml" line="55"/>
        <source>Rain</source>
        <translation>Lluvia</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Ripple/share/qml/main.qml" line="77"/>
        <source>Decay</source>
        <translation>Caída</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/ScanLines/share/qml/main.qml" line="54"/>
        <source>Show lines</source>
        <translation>Mostrar líneas</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/ScanLines/share/qml/main.qml" line="67"/>
        <source>Hide lines</source>
        <translation>Ocultar líneas</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/ScanLines/share/qml/main.qml" line="80"/>
        <source>Hide color</source>
        <translation>Color de la piel</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/ScanLines/share/qml/main.qml" line="84"/>
        <source>Choose the hide color</source>
        <translation>Elija el color de la piel</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Scroll/share/qml/main.qml" line="44"/>
        <source>Vertical Sync</source>
        <translation>Sincronización vertical</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Scroll/share/qml/main.qml" line="69"/>
        <source>Noise</source>
        <translation>Ruido</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Shagadelic/share/qml/main.qml" line="33"/>
        <source>Mask</source>
        <translation>Máscara</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Swirl/share/qml/main.qml" line="38"/>
        <source>Degrees</source>
        <translation>Grados</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Temperature/share/qml/main.qml" line="38"/>
        <source>Temperature</source>
        <translation>Temperatura</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/VideoCapture/share/qml/main.qml" line="215"/>
        <source>Video format</source>
        <translation>Formato de vídeo</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/VideoCapture/share/qml/main.qml" line="253"/>
        <source>Resolution</source>
        <translation>Resolución</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/VideoCapture/share/qml/main.qml" line="295"/>
        <source>FPS</source>
        <translation>FPS</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/VideoCapture/share/qml/main.qml" line="344"/>
        <source>Reset</source>
        <translation>Restablecer</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Vignette/share/qml/main.qml" line="83"/>
        <source>Aspect</source>
        <translation>Aspecto</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Vignette/share/qml/main.qml" line="106"/>
        <source>Scale</source>
        <translation>Escala</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Vignette/share/qml/main.qml" line="129"/>
        <source>Softness</source>
        <translation>Suavidad</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Vignette/share/qml/main.qml" line="73"/>
        <source>Choose the vignette color</source>
        <translation>Elija el color de la viñeta</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/VirtualCamera/share/qml/main.qml" line="61"/>
        <source>Devices</source>
        <translation>Dispositivos</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/VirtualCamera/share/qml/main.qml" line="78"/>
        <source>Add</source>
        <translation>Añadir</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/VirtualCamera/share/qml/main.qml" line="89"/>
        <source>Edit</source>
        <translation>Editar</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/VirtualCamera/share/qml/main.qml" line="102"/>
        <source>Remove</source>
        <translation>Eliminar</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/VirtualCamera/share/qml/main.qml" line="113"/>
        <source>Remove All</source>
        <translation>Eliminar todo</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/VirtualCamera/share/qml/main.qml" line="134"/>
        <source>Description</source>
        <translation>Descripción</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/VirtualCamera/share/qml/main.qml" line="140"/>
        <source>Camera name (optional)</source>
        <translation>Nombre de la cámara (opcional)</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/VirtualCamera/share/qml/main.qml" line="263"/>
        <source>Error creating camera</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/VirtualCamera/share/qml/main.qml" line="152"/>
        <source>Ok</source>
        <translation>Aceptar</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/VirtualCamera/share/qml/main.qml" line="195"/>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/VirtualCamera/share/qml/main.qml" line="249"/>
        <source>This system is not supported yet</source>
        <translation>Este sistema aún no es compatible</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Warp/share/qml/main.qml" line="28"/>
        <source>Ripples</source>
        <translation>Ondulaciones</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Wave/share/qml/main.qml" line="116"/>
        <source>Phase</source>
        <translation>Etapa</translation>
    </message>
</context>
</TS>
